{"": "", "Adapters": "Ba\u011fda\u015ft\u0131r\u0131c\u0131lar", "Batteries": "Piller", "Charging": "\u015earj oluyor", "Discharging at {{battery.rate}} W": "{{battery.rate}} W kullan\u0131l\u0131yor", "Hibernate": "Haz\u0131rda bekleme", "No adapters detected": "Adapt\u00f6r bulunamad\u0131", "No batteries detected": "Pil bulunamad\u0131", "Not available": "Kullan\u0131labilir de\u011fil", "Plugged in": "Ba\u011fland\u0131", "Power": "G\u00fc\u00e7", "Power off": "G\u00fcc\u00fc kapat", "Reboot": "Yeniden ba\u015flat", "Suspend": "Ask\u0131ya al", "System uptime": "Sistem aktif s\u00fcresi", "{{battery.voltage}} V": "{{battery.voltage}} V", "Power state": "G\u00fc\u00e7 durumu", "Shutdown and reboot the system": "Sistemi yeniden ba\u015flat", "Power management": "", "Warning": "", "Are you sure you want to shutdown the system now?": "", "Shutdown": "", "Cancel": "", "Are you sure you want to reboot the system now?": "", "System is rebooting. We will try to reconnect with it.": "", "Are you sure you want to suspend the system now?": "", "System is suspending": "", "Are you sure you want to hibernate the system now?": "", "System is hibernating": ""}