{"": "", "Adapters": "\u9002\u914d\u5668", "Batteries": "\u7535\u6c60", "Charging": "\u5145\u7535\u4e2d", "Discharging at {{battery.rate}} W": "\u6b63\u5728\u653e\u7535\u4e8e{{battery.rate}}\u74e6", "Hibernate": "\u4f11\u7720", "No adapters detected": "\u6ca1\u6709\u68c0\u6d4b\u5230\u4efb\u4f55\u9002\u914d\u5668", "No batteries detected": "\u6ca1\u6709\u68c0\u6d4b\u5230\u4efb\u4f55\u7535\u6c60", "Not available": "\u4e0d\u53ef\u7528", "Plugged in": "\u5df2\u63d2\u5165", "Power": "\u7535\u6e90", "Power off": "\u5173\u95ed\u7535\u6e90", "Reboot": "\u91cd\u542f", "Suspend": "\u6302\u8d77", "System uptime": "\u7cfb\u7edf\u8fd0\u884c\u65f6\u95f4", "{{battery.voltage}} V": "{{battery.voltage}} \u4f0f", "Power state": "\u7535\u6e90\u72b6\u6001", "Shutdown and reboot the system": "\u5173\u95ed\u5e76\u91cd\u65b0\u542f\u52a8\u7cfb\u7edf", "Power management": "", "Warning": "", "Are you sure you want to shutdown the system now?": "", "Shutdown": "", "Cancel": "", "Are you sure you want to reboot the system now?": "", "System is rebooting. We will try to reconnect with it.": "", "Are you sure you want to suspend the system now?": "", "System is suspending": "", "Are you sure you want to hibernate the system now?": "", "System is hibernating": ""}