{"": "", "Adapters": "Vmesniki", "Batteries": "Baterije", "Charging": "Polnjenje", "Discharging at {{battery.rate}} W": "Praznjenje pri {{battery.rate}} W", "Hibernate": "Hibernacija", "No adapters detected": "Ni zaznanih vmesnikov", "No batteries detected": "Ni zaznanih baterij", "Not available": "Ni na voljo", "Plugged in": "Priklopljeno v omre\u017eje", "Power": "Napajanje", "Power off": "Izklop", "Reboot": "Ponovni zagon", "Suspend": "Mirovanje", "System uptime": "\u010cas od zagona sistema", "{{battery.voltage}} V": "{{battery.voltage}} V", "Power state": "Stanje porabe", "Shutdown and reboot the system": "Zaustavi in ponovno za\u017eeni sistem", "Power management": "", "Warning": "", "Are you sure you want to shutdown the system now?": "", "Shutdown": "", "Cancel": "", "Are you sure you want to reboot the system now?": "", "System is rebooting. We will try to reconnect with it.": "", "Are you sure you want to suspend the system now?": "", "System is suspending": "", "Are you sure you want to hibernate the system now?": "", "System is hibernating": ""}