{"": "", "Adapters": "Adaptadores", "Batteries": "Bater\u00edas", "Charging": "Cargando", "Discharging at {{battery.rate}} W": "Descargando a {{battery.rate}} W", "Hibernate": "Hibernar", "No adapters detected": "No adaptadores detectados", "No batteries detected": "No bater\u00edas detectadas", "Not available": "No disponible", "Plugged in": "Conectado", "Power": "Energ\u00eda", "Power off": "Apagado", "Reboot": "Reiniciar", "Suspend": "Suspender", "System uptime": "Tiempo de actividad del sistema", "{{battery.voltage}} V": "{{battery.voltage}} V", "Power state": "Estado de alimentaci\u00f3n", "Shutdown and reboot the system": "Apagar y reiniciar el sistema", "Power management": "", "Warning": "", "Are you sure you want to shutdown the system now?": "", "Shutdown": "", "Cancel": "", "Are you sure you want to reboot the system now?": "", "System is rebooting. We will try to reconnect with it.": "", "Are you sure you want to suspend the system now?": "", "System is suspending": "", "Are you sure you want to hibernate the system now?": "", "System is hibernating": ""}