{"": "", "Adapters": "Adaptadores", "Batteries": "Baterias", "Charging": "Carregando", "Discharging at {{battery.rate}} W": "Descarregando em {{battery.rate}} W", "Hibernate": "Hibernar", "No adapters detected": "Nenhum adaptador detectado", "No batteries detected": "Nenhuma bateria detectada", "Not available": "Indispon\u00edvel", "Plugged in": "Conectado", "Power": "Energia", "Power off": "Desligar", "Reboot": "Reiniciar", "Suspend": "Suspender", "System uptime": "Tempo ligado do sistema", "{{battery.voltage}} V": "{{battery.voltage}} V", "Power state": "Estado de energia", "Shutdown and reboot the system": "Desligamento e reinicializa\u00e7\u00e3o do sistema", "Power management": "", "Warning": "", "Are you sure you want to shutdown the system now?": "", "Shutdown": "", "Cancel": "", "Are you sure you want to reboot the system now?": "", "System is rebooting. We will try to reconnect with it.": "", "Are you sure you want to suspend the system now?": "", "System is suspending": "", "Are you sure you want to hibernate the system now?": "", "System is hibernating": ""}