{"": "", "Adapters": "\uc5b4\ub311\ud130", "Batteries": "\ubc30\ud130\ub9ac", "Charging": "\ucda9\uc804\uc911", "Discharging at {{battery.rate}} W": "", "Hibernate": "\ucd5c\ub300 \uc808\uc804 \ubaa8\ub4dc", "No adapters detected": "", "No batteries detected": "", "Not available": "", "Plugged in": "", "Power": "\uc804\uc6d0", "Power off": "\uc2dc\uc2a4\ud15c \uc885\ub8cc", "Reboot": "\uc7ac\ubd80\ud305", "Suspend": "\uc77c\uc2dc\uc815\uc9c0", "System uptime": "\uc2dc\uc2a4\ud15c \uac00\ub3d9 \uc2dc\uac04", "{{battery.voltage}} V": "", "Power state": "\uc804\uc6d0 \uc0c1\ud0dc", "Shutdown and reboot the system": "\uc2dc\uc2a4\ud15c \uc885\ub8cc \ubc0f \uc7ac\ubd80\ud305", "Power management": "", "Warning": "", "Are you sure you want to shutdown the system now?": "", "Shutdown": "", "Cancel": "", "Are you sure you want to reboot the system now?": "", "System is rebooting. We will try to reconnect with it.": "", "Are you sure you want to suspend the system now?": "", "System is suspending": "", "Are you sure you want to hibernate the system now?": "", "System is hibernating": ""}