{"": "", "Adapters": "Adapter", "Batteries": "Batterien", "Charging": "Aufladen", "Discharging at {{battery.rate}} W": "Entladung mit {{battery.rate}} W", "Hibernate": "Ruhezustand", "No adapters detected": "Keine Adapter erkannt", "No batteries detected": "Keine Akkus erkannt", "Not available": "Nicht verf\u00fcgbar", "Plugged in": "Eingesteckt", "Power": "Power", "Power off": "Ausschalten", "Reboot": "Neustart", "Suspend": "Bereitschaft", "System uptime": "Betriebszeit", "{{battery.voltage}} V": "{{battery.voltage}} V", "Power state": "Status", "Shutdown and reboot the system": "Herunterfahren und Neustart des Systems", "Power management": "Energieverwaltung", "Warning": "Warnung", "Are you sure you want to shutdown the system now?": "Sind Sie sicher, dass Sie das System jetzt herunterfahren m\u00f6chten?", "Shutdown": "Herunterfahren", "Cancel": "Abbrechen", "Are you sure you want to reboot the system now?": "Sind Sie sicher, dass Sie das System jetzt neu starten m\u00f6chten?", "System is rebooting. We will try to reconnect with it.": "System wird neu gestartet. Wir werden versuchen, die Verbindung wieder herzustellen.", "Are you sure you want to suspend the system now?": "Sind Sie sicher, dass Sie das System in den Bereitschaftszustand versetzen m\u00f6chten?", "System is suspending": "System wird in den Bereitschaftsmodus versetzt", "Are you sure you want to hibernate the system now?": "Sind Sie sicher, dass Sie das System in den Ruhezustand versetzen m\u00f6chten?", "System is hibernating": "System wird in den Ruhezustand versetzt"}