{"": "", "Adapters": "Adaptery", "Batteries": "Baterie", "Charging": "", "Discharging at {{battery.rate}} W": "", "Hibernate": "Hibernacja", "No adapters detected": "Nie wykryto adapter\u00f3w", "No batteries detected": "", "Not available": "", "Plugged in": "", "Power": "Zasilanie", "Power off": "Wy\u0142\u0105cz", "Reboot": "Uruchom ponownie", "Suspend": "", "System uptime": "", "{{battery.voltage}} V": "{{battery.voltage}} V", "Power state": "Stan zasilania", "Shutdown and reboot the system": "", "Power management": "", "Warning": "", "Are you sure you want to shutdown the system now?": "", "Shutdown": "", "Cancel": "", "Are you sure you want to reboot the system now?": "", "System is rebooting. We will try to reconnect with it.": "", "Are you sure you want to suspend the system now?": "", "System is suspending": "", "Are you sure you want to hibernate the system now?": "", "System is hibernating": ""}