{"": "", "Adapters": "Adapt\u00e9ry", "Batteries": "Baterie", "Charging": "Nab\u00edjen\u00ed", "Discharging at {{battery.rate}} W": "Vyb\u00edjen\u00ed na {{battery.rate}} W", "Hibernate": "Hibernace", "No adapters detected": "Nebyly zji\u0161t\u011bny \u017e\u00e1dn\u00e9 adapt\u00e9ry", "No batteries detected": "Nebyly zji\u0161t\u011bny \u017e\u00e1dn\u00e9 baterie", "Not available": "Nen\u00ed k dispozici", "Plugged in": "P\u0159ipojena", "Power": "Nap\u00e1jen\u00ed", "Power off": "Vypnout", "Reboot": "Restartovat", "Suspend": "Pozastavit", "System uptime": "Doba provozu syst\u00e9mu", "{{battery.voltage}} V": "{{battery.voltage}} V", "Power state": "Stav nap\u00e1jen\u00ed", "Shutdown and reboot the system": "Vypnut a restartovat syst\u00e9m", "Power management": "", "Warning": "", "Are you sure you want to shutdown the system now?": "", "Shutdown": "", "Cancel": "", "Are you sure you want to reboot the system now?": "", "System is rebooting. We will try to reconnect with it.": "", "Are you sure you want to suspend the system now?": "", "System is suspending": "", "Are you sure you want to hibernate the system now?": "", "System is hibernating": ""}