{"": "", "Adapters": "Adapters", "Batteries": "Accu\u2019s", "Charging": "Aan het opladen", "Discharging at {{battery.rate}} W": "Ontladen op {{battery.rate}} W", "Hibernate": "Slaapstand", "No adapters detected": "Geen adapters gedetecteerd", "No batteries detected": "Geen batterijen gedetecteerd", "Not available": "Niet beschikbaar", "Plugged in": "Aangesloten", "Power": "Vermogen", "Power off": "", "Reboot": "", "Suspend": "", "System uptime": "", "{{battery.voltage}} V": "{{battery.voltage}} V", "Power state": "Vermogen status", "Shutdown and reboot the system": "Afsluiten en opnieuw opstarten van het systeem", "Power management": "", "Warning": "", "Are you sure you want to shutdown the system now?": "", "Shutdown": "", "Cancel": "", "Are you sure you want to reboot the system now?": "", "System is rebooting. We will try to reconnect with it.": "", "Are you sure you want to suspend the system now?": "", "System is suspending": "", "Are you sure you want to hibernate the system now?": "", "System is hibernating": ""}