{"": "", "Adapters": "Adattatori", "Batteries": "Batterie", "Charging": "In carica", "Discharging at {{battery.rate}} W": "Scaricamento a {{battery.rate}} W", "Hibernate": "Ibernazione", "No adapters detected": "Nessun adattatore rilevato", "No batteries detected": "Batterie non rilevate", "Not available": "Non disponibile", "Plugged in": "Collegato", "Power": "Alimentazione", "Power off": "Spegni", "Reboot": "Riavvia", "Suspend": "Sospensione", "System uptime": "Tempo di accensione del sistema", "{{battery.voltage}} V": "{{battery.voltage}} V", "Power state": "Stato di alimentazione", "Shutdown and reboot the system": "Arresto e riavvio del sistema", "Power management": "", "Warning": "", "Are you sure you want to shutdown the system now?": "", "Shutdown": "", "Cancel": "", "Are you sure you want to reboot the system now?": "", "System is rebooting. We will try to reconnect with it.": "", "Are you sure you want to suspend the system now?": "", "System is suspending": "", "Are you sure you want to hibernate the system now?": "", "System is hibernating": ""}