{"": "", "Adapters": "", "Batteries": "", "Charging": "", "Discharging at {{battery.rate}} W": "", "Hibernate": "", "No adapters detected": "", "No batteries detected": "", "Not available": "", "Plugged in": "", "Power": "\u0416\u0438\u0432\u043b\u0435\u043d\u043d\u044f", "Power off": "", "Reboot": "\u041f\u0435\u0440\u0435\u0437\u0430\u0432\u0430\u043d\u0442\u0430\u0436\u0438\u0442\u0438", "Suspend": "", "System uptime": "", "{{battery.voltage}} V": "", "Power state": "", "Shutdown and reboot the system": "", "Power management": "", "Warning": "", "Are you sure you want to shutdown the system now?": "", "Shutdown": "", "Cancel": "", "Are you sure you want to reboot the system now?": "", "System is rebooting. We will try to reconnect with it.": "", "Are you sure you want to suspend the system now?": "", "System is suspending": "", "Are you sure you want to hibernate the system now?": "", "System is hibernating": ""}