{"": "", "Adapters": "Adaptiloj", "Batteries": "Baterioj", "Charging": "", "Discharging at {{battery.rate}} W": "", "Hibernate": "", "No adapters detected": "", "No batteries detected": "", "Not available": "", "Plugged in": "", "Power": "", "Power off": "", "Reboot": "", "Suspend": "", "System uptime": "", "{{battery.voltage}} V": "{{battery.voltage}} V", "Power state": "", "Shutdown and reboot the system": "", "Power management": "", "Warning": "", "Are you sure you want to shutdown the system now?": "", "Shutdown": "", "Cancel": "", "Are you sure you want to reboot the system now?": "", "System is rebooting. We will try to reconnect with it.": "", "Are you sure you want to suspend the system now?": "", "System is suspending": "", "Are you sure you want to hibernate the system now?": "", "System is hibernating": ""}