{"": "", "Adapters": "Adaptor", "Batteries": "Baterai", "Charging": "Pengisian", "Discharging at {{battery.rate}} W": "Pengosongan di {{battery.rate}} W", "Hibernate": "Hibernate", "No adapters detected": "Tidak ada adapter yang terdeteksi", "No batteries detected": "Tidak ada baterai yang terdeteksi", "Not available": "Tidak tersedia", "Plugged in": "Terpasang", "Power": "Daya", "Power off": "Matikan daya", "Reboot": "Nyalakan Ulang", "Suspend": "Tunda", "System uptime": "Sistem uptime", "{{battery.voltage}} V": "{{battery.voltage}} V", "Power state": "Status daya", "Shutdown and reboot the system": "Shutdown dan reboot sistem", "Power management": "", "Warning": "", "Are you sure you want to shutdown the system now?": "", "Shutdown": "", "Cancel": "", "Are you sure you want to reboot the system now?": "", "System is rebooting. We will try to reconnect with it.": "", "Are you sure you want to suspend the system now?": "", "System is suspending": "", "Are you sure you want to hibernate the system now?": "", "System is hibernating": ""}