{"": "", "Adapters": "Adaptateurs", "Batteries": "Batteries", "Charging": "Rechargement en cours", "Discharging at {{battery.rate}} W": "D\u00e9chargement \u00e0 {{battery.rate}} W", "Hibernate": "Mise en veille prolong\u00e9e", "No adapters detected": "Aucun adaptateur d\u00e9tect\u00e9", "No batteries detected": "Aucune batterie d\u00e9tect\u00e9e", "Not available": "Pas disponible", "Plugged in": "Branch\u00e9", "Power": "Allumer", "Power off": "\u00c9teindre", "Reboot": "Red\u00e9marrer", "Suspend": "Suspendre", "System uptime": "Dur\u00e9e de fonctionnement du syst\u00e8me", "{{battery.voltage}} V": "{{battery.voltage}} V", "Power state": "\u00c9tat de l'alimentation", "Shutdown and reboot the system": "Arr\u00eater et red\u00e9marrer le syst\u00e8me", "Power management": "Gestion de l\u2019alimentation", "Warning": "Avertissement", "Are you sure you want to shutdown the system now?": "\u00cates-vous sur de vouloir \u00e9teindre le syst\u00e8me maintenant ?", "Shutdown": "\u00c9teindre", "Cancel": "Annuler", "Are you sure you want to reboot the system now?": "\u00cates-vous s\u00fbr de vouloir red\u00e9marrer le syst\u00e8me maintenant ?", "System is rebooting. We will try to reconnect with it.": "Le syst\u00e8me red\u00e9marre. Nous allons essayer de s'y reconnecter.", "Are you sure you want to suspend the system now?": "\u00cates-vous s\u00fbr de vouloir mettre le syst\u00e8me en veille maintenant ?", "System is suspending": "Le syst\u00e8me est en veille", "Are you sure you want to hibernate the system now?": "\u00cates-vous s\u00fbr de vouloir mettre en veille prolong\u00e9e le syst\u00e8me maintenant ?", "System is hibernating": "Le syst\u00e8me est en veille prolong\u00e9e"}